@@ -13,12 +13,24 @@
 #endif
 
 #include <stdio.h>
-#include <getopt.h>
 #include <stdlib.h>
+#include <unistd.h>
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
 #include "protos.h"
 
 #ifdef HAVE_GETOPT_LONG
 #  define GETOPT_LONG getopt_long
+
+static struct option long_options[] =
+{
+  {"delete",  1, 0, 'd'},
+  {"list",    1, 0, 'l'},
+  {"replace", 1, 0, 'r'},
+  {"version", 0, 0, 'v'}
+};
+
 #else /* not HAVE_GETOPT_LONG */
 #  define GETOPT_LONG(argc,argv,optstr,lopts,lidx) getopt(argc,argv,optstr)
 #endif /* not HAVE_GETOPT_LONG */
@@ -26,23 +38,18 @@
 static void
 usage(char *progname)
 {
-  printf("Usage: %s [-v|-d|-r <path>] <program>\n\n", progname);
+  printf("Usage: %s [-v|-d|-r <path>] <program> [<program> ...]\n\n",
+         progname);
   printf("   -v|--version                Display program version number\n");
   printf("   -d|--delete                 Delete current rpath setting\n");
   printf("   -r <path>|--replace <path>  Replace current rpath setting\n");
   printf("                               with the path given\n");
+  printf("   -l|--list                   List the current rpath (default)\n");
 #ifndef HAVE_GETOPT_LONG
   printf("\n *** The long options are not available on this platform\n");
 #endif /* not HAVE_GETOPT_LONG */
 }
 
-static struct option long_options[] =
-{
-  {"delete",  1, 0, 'd'},
-  {"replace", 1, 0, 'r'},
-  {"version", 0, 0, 'v'}
-};
-
 int
 main(int argc, char * const argv[])
 {
@@ -58,7 +65,7 @@ main(int argc, char * const argv[])
     }
 
   do {
-    opt = GETOPT_LONG(argc, argv, "dr:v", long_options, &option_index);
+    opt = GETOPT_LONG(argc, argv, "dlr:v", long_options, &option_index);
     switch (opt)
       {
       case 'd':
@@ -71,6 +78,9 @@ main(int argc, char * const argv[])
         printf("%s version %s\n", PACKAGE, VERSION);
         exit(0);
         break;
+      case 'l': /* This is the default action */
+        newpath = NULL;
+        break;
       case -1:
         break;
       default:
@@ -80,11 +90,14 @@ main(int argc, char * const argv[])
       }
   } while (-1 != opt);
 
-  if (remove)
-    killrpath(argv[optind]);
-  else
-    /* list by default, replace if path is set */
-    chrpath(argv[optind], newpath);
+  while (optind < argc)
+    {
+      if (remove)
+        killrpath(argv[optind++]);
+      else
+        /* list by default, replace if path is set */
+        chrpath(argv[optind++], newpath);
+    }
 
   return 0;
 }
